@@ -101,9 +101,12 @@ class ThreadPoolExecutorShrinkAble(Executor, LoggerMixin, LoggerLevelSetterMixin
         :param max_workers:
         :param thread_name_prefix:
         """
-        self._max_workers = max_workers if max_workers is not None else (os.cpu_count() or 1) * 5
+        # print(max_workers)
+        self._max_workers = max_workers or (os.cpu_count() or 1) * 5
         self._thread_name_prefix = thread_name_prefix
-        self.work_queue = self._work_queue = queue.Queue(max_workers or 10)
+        # print(self._max_workers)
+        # self.work_queue = self._work_queue = queue.Queue(self._max_workers or 10)
+        self.work_queue = self._work_queue = queue.Queue(10)
         # self._threads = set()
         self._threads = weakref.WeakSet()
         self._lock_compute_threads_free_count = threading.Lock()
