@@ -10,6 +10,7 @@ import abc
 import copy
 # from multiprocessing import Process
 import datetime
+import pytz
 import json
 import logging
 import sys
@@ -29,7 +30,7 @@ import asyncio
 import pymongo
 from pymongo import IndexModel
 from pymongo.errors import PyMongoError
-
+from apscheduler.schedulers.background import BackgroundScheduler
 # noinspection PyUnresolvedReferences
 from nb_log import LoggerLevelSetterMixin, LogManager, nb_print, LoggerMixin, \
     LoggerMixinDefaultWithFileHandler, stdout_write, stderr_write, is_main_process, only_print_on_main_process
@@ -253,17 +254,6 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
         """
 
         :return:
-        """
-        """
-        def ff():
-            RabbitmqConsumer('queue_test', consuming_function=f3, concurrent_num=20, msg_schedule_time_intercal=2, log_level=10, logger_prefix='yy平台消费', is_consuming_function_use_multi_params=True).start_consuming_message()
-            RabbitmqConsumer('queue_test2', consuming_function=f4, concurrent_num=20, msg_schedule_time_intercal=4, log_level=10, logger_prefix='zz平台消费', is_consuming_function_use_multi_params=True).start_consuming_message()
-            AbstractConsumer.join_shedual_task_thread()            # 如果开多进程启动消费者，在linux上需要这样写下这一行。
-
-
-        if __name__ == '__main__':
-            [Process(target=ff).start() for _ in range(4)]
-
         """
         ConsumersManager.join_all_consumer_shedual_task_thread()
 
@@ -271,7 +261,7 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
     def __init__(self, queue_name, *, consuming_function: Callable = None, function_timeout=0, concurrent_num=50,
                  specify_concurrent_pool=None, specify_async_loop=None, concurrent_mode=1,
                  max_retry_times=3, log_level=10, is_print_detail_exception=True, is_show_message_get_from_broker=False,
-                 msg_schedule_time_intercal=0.0, qps: float = 0, is_using_distributed_frequency_control=False,
+                 qps: float = 0, is_using_distributed_frequency_control=False,
                  msg_expire_senconds=0, is_send_consumer_hearbeat_to_redis=False,
                  logger_prefix='', create_logger_file=True, do_task_filtering=False,
                  task_filtering_expire_seconds=0, is_consuming_function_use_multi_params=True,
@@ -295,8 +285,7 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
         :param log_level: # 这里是设置消费者 发布者日志级别的，如果不想看到很多的细节显示信息，可以设置为 20 (logging.INFO)。
         :param is_print_detail_exception:函数出错时候时候显示详细的错误堆栈，占用屏幕太多
         :param is_show_message_get_from_broker: 从中间件取出消息时候时候打印显示出来
-        :param msg_schedule_time_intercal:消息调度的时间间隔，用于控频
-        :param qps:指定1秒内的函数执行次数，qps会覆盖msg_schedule_time_intercal，一会废弃msg_schedule_time_intercal这个参数。
+        :param qps:指定1秒内的函数执行次数，qps会覆盖msg_schedule_time_intercal，以后会废弃msg_schedule_time_intercal这个参数。
         :param is_using_distributed_frequency_control: 是否使用分布式空频（依赖redis计数），默认只对当前实例化的消费者空频有效。假如实例化了2个qps为10的使用同一队列名的消费者，
                并且都启动，则每秒运行次数会达到20。如果使用分布式空频则所有消费者加起来的总运行次数是10。
         :param is_send_consumer_hearbeat_to_redis   时候将发布者的心跳发送到redis，有些功能的实现需要统计活跃消费者。因为有的中间件不是真mq。
@@ -376,9 +365,7 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
         self._is_show_message_get_from_broker = is_show_message_get_from_broker
 
         self._qps = qps
-        if qps != 0:
-            msg_schedule_time_intercal = 1.0 / qps  # 使用qps覆盖消息调度间隔，以qps为准，以后废弃msg_schedule_time_intercal这个参数。
-        self._msg_schedule_time_intercal = msg_schedule_time_intercal if msg_schedule_time_intercal > 0.001 else 0.001
+        self._msg_schedule_time_intercal = 0 if qps == 0 else 1.0 / qps
 
         self._is_using_distributed_frequency_control = is_using_distributed_frequency_control
         self._is_send_consumer_hearbeat_to_redis = is_send_consumer_hearbeat_to_redis or is_using_distributed_frequency_control
@@ -444,6 +431,9 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
 
         self.consumer_identification = f'{socket.gethostname()}_{time_util.DatetimeConverter().datetime_str.replace(":", "-")}_{os.getpid()}_{id(self)}'
 
+        self._delay_task_scheduler = BackgroundScheduler(timezone=frame_config.TIMEZONE)
+        self._delay_task_scheduler.start()
+
         self.custom_init()
 
         atexit.register(self.join_shedual_task_thread)
@@ -533,7 +523,7 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
     def __get_priority_conf(self, kw: dict, broker_task_config_key: str):
         broker_task_config = kw['body'].get('extra', {}).get(broker_task_config_key, None)
         if broker_task_config is None:
-            return getattr(self, f'_{broker_task_config_key}')
+            return getattr(self, f'_{broker_task_config_key}',None)
         else:
             return broker_task_config
 
@@ -765,10 +755,23 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
                 f'超过了指定的 {msg_expire_senconds_priority} 秒，丢弃任务')
             self._confirm_consume(kw)
             return 0
-        if self._concurrent_mode == 5:  # 单线程
-            self._run(kw)
+        msg_eta = self.__get_priority_conf(kw, 'eta')
+        msg_countdown = self.__get_priority_conf(kw, 'countdown')
+        run_date = None
+        if msg_countdown:
+            run_date = datetime.datetime.now(tz=pytz.timezone(frame_config.TIMEZONE)) + datetime.timedelta(seconds=msg_countdown)
+        if msg_eta:
+            run_date = time_util.DatetimeConverter(msg_eta).datetime_obj
+        if run_date:
+            if self._concurrent_mode == 5:  # 单线程
+                self._delay_task_scheduler.add_job(self._run,'date', run_date=run_date, args=(kw,))
+            else:
+                self._delay_task_scheduler.add_job(self.concurrent_pool.submit,'date', run_date=run_date, args=(self._run, kw))
         else:
-            self.concurrent_pool.submit(self._run, kw)
+            if self._concurrent_mode == 5:  # 单线程
+                self._run(kw)
+            else:
+                self.concurrent_pool.submit(self._run, kw)
         if self._is_using_distributed_frequency_control:  # 如果是需要分布式控频。
             active_num = self._distributed_consumer_statistics.active_consumer_num
             self.__frequency_control(self._qps / active_num, self._msg_schedule_time_intercal * active_num)
