@@ -10,12 +10,13 @@ import time
 import typing
 from functools import wraps
 from threading import Lock
+import datetime
 import amqpstorm
 from kombu.exceptions import KombuError
 from pika.exceptions import AMQPError as PikaAMQPError
 
 from nb_log import LoggerLevelSetterMixin, LogManager, LoggerMixin
-from function_scheduling_distributed_framework.utils import decorators, RedisMixin
+from function_scheduling_distributed_framework.utils import decorators, RedisMixin,time_util
 from function_scheduling_distributed_framework import frame_config
 
 
@@ -60,17 +61,36 @@ class PriorityConsumingControlConfig:
     def __init__(self, function_timeout: float = None, max_retry_times: int = None,
                  is_print_detail_exception: bool = None,
                  msg_expire_senconds: int = None,
-                 is_using_rpc_mode: bool = None):
+                 is_using_rpc_mode: bool = None,
+                 countdown :typing.Union[float,int]= 0,
+                 eta : datetime.datetime = None
+                 ):
+        """
+
+        :param function_timeout: 超时杀死
+        :param max_retry_times:
+        :param is_print_detail_exception:
+        :param msg_expire_senconds:
+        :param is_using_rpc_mode: rpc模式才能在发布端获取结果
+        :param eta: 规定什么时候运行
+        :param countdown: 规定多少秒后运行
+        """
         self.function_timeout = function_timeout
         self.max_retry_times = max_retry_times
         self.is_print_detail_exception = is_print_detail_exception
         self.msg_expire_senconds = msg_expire_senconds
         self.is_using_rpc_mode = is_using_rpc_mode
+        if countdown and eta:
+            raise ValueError('不能同时设置eta和countdown')
+        self.eta = eta
+        self.countdown = countdown
+
 
     def to_dict(self):
+        if isinstance(self.countdown,datetime.datetime):
+            self.countdown = time_util.DatetimeConverter(self.countdown).datetime_str
         return self.__dict__
 
-
 class PublishParamsChecker(LoggerMixin):
     """
     发布的任务的函数参数检查，使发布的任务在消费时候不会出现低级错误。
@@ -104,6 +124,17 @@ class PublishParamsChecker(LoggerMixin):
                              f'必须是 {self.all_arg_name_set} 的子集， 必须是 {self.position_arg_name_set} 的超集')
 
 
+class DelayQueue(LoggerMixin,RedisMixin):
+    def __init__(self,delay_queue_name):
+        self.delay_queue_name = delay_queue_name
+
+    def push(self,msg:str,timestamp):
+        self.redis_db_frame_version3.zadd(self.delay_queue_name,{msg:timestamp},)
+
+    def get_msgs(self):
+        pass
+
+
 class AbstractPublisher(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
 
     def __init__(self, queue_name, log_level_int=10, logger_prefix='', is_add_file_handler=True,
